#!/bin/sh
CP=cp
IDS=IdealDownloadSim

# Markov parameters for 3kph
lsp[1]=0.0058; lsq[1]=0.3613; lsg[1]=0.0003; lsb[1]=0.5947; lsloss[1]="01"; lsspeed[1]="3kph"
lsp[2]=0.0180; lsq[2]=0.2401; lsg[2]=0.0006; lsb[2]=0.7054; lsloss[2]="05"; lsspeed[2]="3kph"
lsp[3]=0.0279; lsq[3]=0.2090; lsg[3]=0.0056; lsb[3]=0.8230; lsloss[3]="10"; lsspeed[3]="3kph"
lsp[4]=0.0461; lsq[4]=0.1680; lsg[4]=0.0116; lsb[4]=0.8920; lsloss[4]="20"; lsspeed[4]="3kph"
# Markov parameters for 120kph
lsp[5]=0.0606; lsq[5]=0.9430; lsg[5]=0.0000; lsb[5]=0.1731; lsloss[5]="01"; lsspeed[5]="120kph"
lsp[6]=0.2707; lsq[6]=0.7095; lsg[6]=0.0000; lsb[6]=0.1954; lsloss[6]="05"; lsspeed[6]="120kph"
lsp[7]=0.4648; lsq[7]=0.5095; lsg[7]=0.0000; lsb[7]=0.2233; lsloss[7]="10"; lsspeed[7]="120kph"
lsp[8]=0.3560; lsq[8]=0.6329; lsg[8]=0.0972; lsb[8]=0.4040; lsloss[8]="20"; lsspeed[8]="120kph"

# Bearer info
#      rate        ; subsampling; 
bearer[0]="266kps";  bearss[0]=4; bearpayload[0]=1288
bearer[1]="398kps";  bearss[1]=1; bearpayload[1]=452
bearer[2]="1066kps"; bearss[2]=1; bearpayload[2]=1288

function computeKt {
    echo $(( ($1 + ($2 - 1)) / $2 )) 
}

# File size info
fs[0]="50KB";   fsize[0]=$(( 50 * 1024 ))          ; fstrials[0]=10000
fs[1]="1MB";    fsize[1]=$(( 1024 * 1024 ))        ; fstrials[1]=10000
fs[2]="3MB";    fsize[2]=$(( 3 * 1024 * 1024 ))    ; fstrials[2]=10000
fs[3]="128MB";  fsize[3]=$(( 128 * 1024 * 1024 ))  ; fstrials[3]=3000 
fs[4]="1800MB"; fsize[4]=$(( 1800 * 1024 * 1024 )) ; fstrials[4]=3000 

function stop { 
    echo $1
    exit 1
}

if [ ! -e IdealDownloadSim.class ]; then
    echo "Compiling java code"
    javac IdealDownloadSim.java Random.java IncrementSelector.java || stop  "Stop: error compiling  IdealDownloadSim.java Random.java IncrementSelector.java" 
fi
 
i=1
while [ $i -le 120 ]; 
do
    fsi=$(( ($i-1) % 5 ))                # File size index
    ### mci=$(( ((($i-1) / 5) % 8 ) + 1  ))           #### WRONG Markov chain index #####
    mci=$(( ((($i-1) / 5) % 4 ) + ((($i-1)/60)*4) + 1  ))  # Markov chain index
    beari=$(( (($i-1) / 20) % 3 ))       # Bearer index
    Kt=$(computeKt ${fsize[$fsi]} ${bearpayload[$beari]})
    
    # Skip SD and HD cases
#   if [ $fsi -lt 3 ]; then
#       i=$(( $i + 1 ))
#       continue
#   fi

    j=0
    ii=$( echo $i | awk '{ printf("%03d", $1)}' )
    rm -f ld${ii}_raw.txt
    while [ $j -lt ${fstrials[$fsi]} ];
    do
        while [ 1 ]; 
        do 
            jj=$(( j % 10 ))
            java ${IDS} ${lsp[${mci}]} ${lsq[$mci]} ${lsg[$mci]} ${lsb[$mci]} ${bearss[$beari]} $Kt $j dummy${jj}.txt > job${jj}.txt &
            # start 10 background jobs then wait
            j=$(( $j + 1 ))
            if [ $(( $jj + 1 )) -eq 10 ]; then
                break;
            fi
        done
        # here
        wait
        jj=0
        # then collect result
        while [ $jj -lt 10 ];
        do
            cat job${jj}.txt >> ld${ii}_raw.txt
            jj=$(( $jj + 1 ))
        done
    done
    head99percent=$(( (${fstrials[$fsi]} / 100) ))
    # sort all trials according to Nt than keep the (#trials/100) one for 99th percentile
    res=`fgrep "Nt=" ld${ii}_raw.txt | sort -k 2 -rn | head -${head99percent} | tail -1`
    echo "LD${ii} $res" 
    i=$(( $i + 1 ))
done
# cleanup
rm -f job?.txt dummy?.txt
